/*******************************************************************************

** Table 10 - Municipal-specific trends **

*******************************************************************************/


clear all
use ../../Data/Final/Data_final.dta, replace
do ../Auxiliary/Estimation_globals.do // Define global variables 


xtset id_towns year
set more off
set matsize 1000

* Trend variables *
gen trend2 = trend^2   

******************************************************

* Column I and II: covariate interactions *
* Allow spending to be related to municipality specific time trends, depending on pre-reform characteristics *

* - Col. I : time trend *

* Generating trend interacted with baseline (year = 2007) characteristics
local baseline_year = 2007 // Choice of baseline year
local j = 1

foreach i of varlist male age education population pop2 pop3 altitude surface density-military non_ordinary  term_limited vote_share1 {
gen b`j' = `i' if year == `baseline_year'
bys id_towns: egen base_`j' = max(b`j')
replace base_`j' = base_`j'*trend if base_`j' !=.
label var base_`j' "`i' `baseline_year' * t"
drop b`j'
local j = `j'+1
}
*

local baseline_controls "base_*"  // These are the interactions


* Column I - estimation *

eststo clear
eststo:  areg  Spese_cc_pc  $x1 $controls_panel $pol_controls `baseline_controls' /*
*/ i.year##i.region_code, cluster(id_towns) absorb(id_towns) 

estadd local year_d "Y" , replace
estadd local year_r "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "Y" , replace


* - Col. II : time dummies *

* Generating time dummies inteacted with baseline (year = 2007) characteristics
capture drop base_*  // Drop previous baseline interactions to use them again

* Time dummies * 
tab year, gen(year)

* Variables in 2007, extended to all years *
local j = 1
foreach i of varlist male age education population pop2 pop3 altitude-surface density-military non_ordinary  term_limited vote_share1{
gen b`j' = `i' if year == `baseline_year'
bys id_towns: egen base_`j' = max(b`j')
drop b`j'
local j = `j'+1
}
*


local baseline_controls "i.year#(c.base_1 c.base_2 c.base_3 c.base_4 c.base_5 c.base_6 c.base_7 c.base_8 c.base_9 c.base_10 c.base_11 c.base_12 c.base_13 c.base_14)"


* Column II - estimation (remove time dummies from estimation since they are already in baseline controls) *
eststo: areg  Spese_cc_pc  $x1 $controls_panel $pol_controls `baseline_controls' , cluster(id_towns) absorb(id_towns) 
estadd local year_d "Y" , replace
estadd local year_r "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "Y" , replace


* Column III and IV: municipality-specific trends *

* - Col. III : Est. pre-reform trends *
*  Bhuller et al, p. 1257, section 6.5 * 

***********************************************************************************
* Preliminar: Progream MYTRENDBETA *
* Program adapted from http://www.stata.com/statalist/archive/2012-02/msg01108.html *

* Input: y, trend, trend^2 *
* Output: Estimated trend coefficients (beta1, beta2) *
* Note: no constant is included, since it is the individual FE *

 prog mytrendbeta, rclass byable(recall)
 version 10.1
 syntax varlist [if] [in],  TRBETA1(varname) TRBETA2(varname)   
 marksample touse
 regress `varlist' if `touse', noconst
 local b1 =  _b[trend] 
 local b2 =  _b[trend2] 
 replace `trbeta1' = `b1' if e(sample) // e(sample) is needed to replace only for the current ID
 replace `trbeta2' = `b2' if e(sample)
 end
 
***********************************************************************************


* 1) Obtain trend coefficients: b1 (coefficient of trend) and b2 (coef. of trend^2) estimated using only pre-reform years *

preserve

keep if year < `baseline_year'
gen b1 = .
gen b2 = .

qui: by id_towns:  mytrendbeta Spese_cc_pc trend trend2, trbeta1(b1) trbeta2(b2)

sort id_towns year
drop if id_towns == id_towns[_n-1] // Keep only one obs. per municipality
save trends.dta, replace

restore

* And merge back *
merge m:1 id_towns using trends.dta
* Not merged: cases in which there is only 1 observation per individual, so no trend is estimated *

erase trends.dta

replace b1 = b1*trend  // v_k*t in Bhuller (2011)
replace b2 = b2*trend  // v_k*t^2

* Column III - estimation *
eststo: areg Spese_cc_pc $x1 $controls_panel $pol_controls b1 b2 i.year##i.region_code, cluster(id_towns) absorb(id_towns)
estadd local year_d "Y" , replace
estadd local year_r "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "Y" , replace



* - Col. IV	 : Trends Est. directly as controls 
* Including municipality-specific trends *

* http://www.stata.com/statalist/archive/2004-06/msg00448.html

* The estimator is numerically different from doing areg with trend-FE interactions, but
* both are consistent. 


* Column IV - Estimation *
xtset id_towns year

eststo: quietly: xi: reg d2.(Spese_cc_pc  $x1 $controls_panel $pol_controls year1-year14), noconst cluster(id_towns)
estadd local year_d "Y" , replace
estadd local year_r "N" , replace
estadd local fixed "Y" , replace
estadd local controls "Y" , replace



* Table 10  *
esttab using ../../Results/Tables/Table_10.tex, replace compress se r2(2) keep(years_minus2 years_minus1 years_0  years_2  years_f_minus2 years_f_minus1 years_f0 years_f2) /*
*/ rename(D2.years_minus2 years_minus2 D2.years_minus1 years_minus1 D2.years_0 years_0 D2.years_2 years_2 /*
*/ D2.years_f_minus2 years_f_minus2 D2.years_f_minus1 years_f_minus1 D2.years_f0 years_f0 D2.years_f2 years_f2  D2.Spese_cc_pc Spese_cc_pc ) /*
*/ label mtitles("Trend" "Dummies" "Pre-estimated" "Controls") booktabs  star(* 0.10 ** 0.05 *** 0.01)  f gaps  nonotes/*
*/ s(controls year_d year_r  fixed r2 N, fmt(0 0 0 0 2 0) label("Controls" "Year Effects" "Year-Region Effects" "Municipality Effects" "\emph{R}$^2$  " "Obs.")) /*
*/ alignment(c)  b(a2) /*
*/ mgroups("Baseline char. interactions" "Individual trends",pattern(1 0 1 0)  prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))  

